<?php

defined( 'ABSPATH' ) || exit;

if ( class_exists( 'Gift_Wrapper_Settings_Page', false ) ) {
	return new Gift_Wrapper_Settings_Page();
}

class Gift_Wrapper_Settings_Page extends WC_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {

		$this->id = 'gift-wrapper';
		$this->label = __( 'Gift Wrapper', 'woocommerce-gift-wrapper' );

		parent::__construct();

	}

	/**
	 * Set Gift Wrapper tab sections.
	 *
	 * @return array
	 */
	protected function get_own_sections() {

		return [
			''                  => __( 'General Options', 'woocommerce-gift-wrapper' ),
			'order_wrapping'    => __( 'Order Wrapping', 'woocommerce-gift-wrapper' ),
			'product_wrapping'  => __( 'Product Wrapping', 'woocommerce-gift-wrapper' ) . ' (PLUS)',
			'language'          => __( 'Language', 'woocommerce-gift-wrapper' ) . ' (PLUS)',
		];

	}

	/**
	 * Get default (general options) settings array
	 *
	 * @return array
	 */
	public function get_settings_for_default_section() {

		$settings[] = [
			'name'          => __( 'Basic Setup Instructions', 'woocommerce-gift-wrapper' ),
			'type'          => 'title',
			'desc'          => '<strong>1.</strong> '
								. sprintf( __( 'Create a new, unique <a href="%s" target="_blank" rel="noopener">WooCommerce product category</a> to hold your gift wrap product(s). Name it anything you\'d like.', 'woocommerce-gift-wrapper' ), admin_url( '/edit-tags.php?taxonomy=product_cat&post_type=product' ) )
								. '<br /><strong>2.</strong> ' . wp_kses_post( sprintf( __( 'Create at least one <a href="%s" target="_blank">WooCommerce product</a> to represent your gift wrap or add-on. Give it a title and a price. It can be hidden from the catalog if you like, but shouldn\'t be private.', 'woocommerce-gift-wrapper' ), admin_url( 'post-new.php?post_type=product' ) ) )
								. '<br /><strong>3.</strong> ' . __( 'Add the product(s) from step 2 to your new, unique WooCommerce product category from step 1.', 'woocommerce-gift-wrapper' )
								. '<br /><strong>4.</strong> ' . sprintf( __( 'Change the "<a href="#" id="wcgwp-wrap-category-link">Gift wrap category</a>" setting below to the product category created in step 1, and save.', 'woocommerce-gift-wrapper' )
								. '<br /><strong>5.</strong> ' . __( 'Review all the settings below, then finish on the <a href="%s" target="_blank" rel="noopener">Order Wrapping</a> options page.', 'woocommerce-gift-wrapper' ), admin_url( 'admin.php?page=wc-settings&tab=gift-wrapper&section=order_wrapping' ) ),
		];
		$settings[]	= [
			'id'            => 'wcgwp_category_id',
			'title'         => __( 'Gift wrap category', 'woocommerce-gift-wrapper' ),
			'desc_tip'      => __( 'Define the category which holds your gift wrap product(s), e.g. your boxes, bags, and gift paper product(s).', 'woocommerce-gift-wrapper' ),
			'type'          => 'select',
			'default'       => 'none',
			'options'       => WC_Gift_Wrap()->settings->product_cats(),
			'custom_attributes' => [
				'data-placeholder' => __( 'Define a Category', 'woocommerce-gift-wrapper' )
			],
			'class'         => 'chosen_select',
			'autoload'      => false,
		];
		$settings[] = [
			'id'            => 'wcgwp_textarea_limit',
			'name'          => __( 'Textarea character limit', 'woocommerce-gift-wrapper' ),
			'desc'          => __( 'Set to 0 (zero) to hide the textarea', 'woocommerce-gift-wrapper-plus' ),
			'desc_tip'      => __( 'How many characters your customer can type when creating their own note for giftwrapping. Defaults to 1000 characters; lower this number if you want shorter notes from your customers.', 'woocommerce-gift-wrapper' ),
			'type'          => 'number',
			'default'       => 1000,
			'autoload'      => false,
		];
		$settings[] = [
			'id'            => '_wcgwp_details',
			'name'          => __( 'Gift wrap details', 'woocommerce-gift-wrapper' ),
			'desc'          => sprintf( __( 'Optional text to give any details or conditions of your gift wrap offering. This string is now set under the <a href="%s" target="_blank" rel="noopener">"Language" (PLUS) tab</a>.', 'woocommerce-gift-wrapper' ), admin_url( 'admin.php?page=wc-settings&tab=gift-wrapper&section=language#wcgwp_strings[add_wrap_for_x]' ) ),
			'desc_tip'      => __( 'This text is not translatable by Wordpress i18n, but can be translated by WPML. Leave this field empty to translate via another means.', 'woocommerce-gift-wrapper' ),
			'type'          => 'text',
			'default'       => '',
			'css'           => 'min-width:50%;height:75px;pointer-events:none;',
			'autoload'      => false,
			'class'         => 'disabled',
		];
		$settings[]	= [
			'id'            => 'wcgwp_multiples',
			'name'          => __( 'Allow Multiples?', 'woocommerce-gift-wrapper' ),
			'desc'          => __( 'Check to allow more than one giftwrap to be added to a product.', 'woocommerce-gift-wrapper' ),
			'desc_tip'      => __( 'PLUS (paid) feature. Allows multiple wrap products to be added to any item.', 'woocommerce-gift-wrapper' ),
			'type'          => 'checkbox',
			'default'       => 'no',
			'class'         => 'wcgwp-plus',
			'autoload'      => false,
		];
		$settings[] = [
			'id'            => 'wcgwp_hide_price',
			'name'          => __( 'Hide price?', 'woocommerce-gift-wrapper' ),
			'desc_tip'      => __( 'PLUS (paid) feature. Should the gift wrap price be hidden? Tip: the price HTML can also be filtered using the \'wcgwp_price_html\' hook.', 'woocommerce-gift-wrapper' ),
			'type'          => 'select',
			'default'       => 'no',
			'options'       => [
				'yes'   => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'    => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'class'         => 'wcgwp-plus',
			'autoload'      => false
		];
		$settings[] = [
			'id'            => 'wcgwp_note_fee',
			'name'          => __( 'Add fee?', 'woocommerce-gift-wrapper' ),
			'desc_tip'      => __( 'PLUS (paid) feature. Do you wish to charge a fee for customers to add a note to their gift wrapping?', 'woocommerce-gift-wrapper' ),
			'type'          => 'select',
			'default'       => 'no',
			'options'       => [
				'yes'   => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'    => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'class'         => 'wcgwp-plus',
			'autoload'      => false
		];
		$settings[] = [
			'id'            => 'wcgwp_note_fee_amount',
			'name'          => __( 'Fee amount', 'woocommerce-gift-wrapper' ),
			'desc_tip'      => __( 'PLUS (paid) feature. Enter the amount you wish to charge to include a note, e.g. 1.00 or 2.50', 'woocommerce-gift-wrapper' ),
			'type'          => 'text',
			'default'       => '0.00',
			'class'         => 'wcgwp-note-fee-amount wcgwp-plus',
			'autoload'      => false
		];
		$settings[] = [
			'type'  => 'sectionend'
		];

		$display = get_option( 'wcgwp_cart_display', 'modal' );

		if ( 'modal' === $display ) {

			// Get array of possible CSS animations
			$animations = WC_Gift_Wrap()->settings->get_animations();

			$settings[] = [
				'name'      => __( 'Modal Options', 'woocommerce-gift-wrapper' ),
				'type'      => 'title',
				'id'        => 'wcgwp-plus-only-modal',
				'desc'      => '<p><strong>' . sprintf( wp_kses( __( 'You have chosen to use a modal (pop-up) to display your wrap. <a href="%s" rel="noopener" target="_blank" class="button btn">Animate modals with Gift Wrapper Plus</a>', 'woocommerce-gift-wrapper' ), [ 'a' => [ 'href' => [], 'target' => [], 'rel' => [], 'class' => [ 'button', 'btn' ] ] ] ), 'https://www.giftwrapper.app' ) . '</strong></p>',
			];
			$settings[] = [
				'id'        => 'wcgwp_modal_animate',
				'name'      => __( 'Animate your modals?', 'woocommerce-gift-wrapper' ),
				'type'      => 'checkbox',
				'default'   => 'no',
				'desc'      => wp_kses_post( sprintf( __( 'Check to animate modals using <a href="%s" target="_blank" rel="noopener">animate.css</a>. Will automatically include extra necessary CSS file and Javascript in pages where modals show.', 'woocommerce-gift-wrapper' ), 'https://animate.style' ) ),
				'desc_tip'  => __( 'You can also choose to instead customize/animate your modals as you choose by overriding included template files.', 'woocommerce-gift-wrapper' ),
				'class'     => 'wcgwp-plus',
				'autoload'  => false,
			];
			$settings[] = [
				'id'        => 'wcgwp_modal_animate_in',
				'name'      => __( 'Entrance animation', 'woocommerce-gift-wrapper' ),
				'type'      => 'select',
				'default'   => 'fadeIn',
				'options'   => $animations['attention_seekers'] + $animations['in'],
				'autoload'  => false,
				'class'     => 'wcgwp-animate-on wcgwp-plus'
			];
			$settings[] = [
				'id'        => 'wcgwp_modal_animate_out',
				'name'      => __( 'Exit animation', 'woocommerce-gift-wrapper' ),
				'type'      => 'select',
				'default'   => 'fadeOut',
				'options'   => $animations['attention_seekers'] + $animations['out'],
				'autoload'  => false,
				'class'     => 'wcgwp-animate-on wcgwp-plus'
			];
			$settings[] = [
				'type' => 'sectionend'
			];

		}

		$settings[] = [
			'name'          => __( 'Advanced Options', 'woocommerce-gift-wrapper' ),
			'type'          => 'title',
			'desc'          => '',
		];
		$settings[] = [
			'id'                => 'wcgwp_lt6_templates',
			'name'              => __( 'Accommodate templates from version 5?', 'woocommerce-gift-wrapper' ),
			'type'              => 'checkbox',
			'default'           => 'no',
			'desc'              => __( 'Version 6.0 of Gift Wrapper includes many template adjustments, and uses AJAX in the cart/checkout instead of a form submit.<br />If you have overwritten the plugin templates with customizations before 6.0 and things broke for you with the 6.0 update, check this box until you can update your templates.', 'woocommerce-gift-wrapper-plus' ),
			'autoload'          => false
		];

		$settings[] = [
			'id'            => 'wcgwp_delete_all',
			'name'          => __( 'Leave No Trace', 'woocommerce-gift-wrapper' ),
			'type'          => 'checkbox',
			'default'       => 'yes',
			'desc'          => __( 'Delete all settings upon plugin uninstall', 'woocommerce-gift-wrapper' ),
			'desc_tip'      => __( 'If you plan on deleting this plugin and not coming back, and want to keep your Wordpress database tables tidy, check this box, save settings, then delete the plugin.', 'woocommerce-gift-wrapper' ),
			'autoload'      => false
		];

		$settings[] = [
			'type' => 'sectionend'
		];

		return $settings;

	}

	/**
	 * Get order wrapping settings array
	 *
	 * @return array
	 */
	public function get_settings_for_order_wrapping_section() {

		$settings[] = [
			'name' => __( 'Order Gift Wrapping Settings', 'woocommerce-gift-wrapper' ),
			'type' => 'title',
			'desc' => __( 'These settings apply to per-order wrap options in the cart and checkout areas, not cart item (per-item) or per-product wrapping.', 'woocommerce-gift-wrapper' )
						. '<br />'
						. wp_kses_post( sprintf( __( '<a href="%s">Per-product and cart item gift wrapping options are in a separate settings tab</a> (PLUS)', 'woocommerce-gift-wrapper' ), admin_url( 'admin.php?page=wc-settings&tab=gift-wrapper&section=product_wrapping' ) ) ),
		];
		$settings[] = [
			'id'       => 'wcgwp_cart_hook',
			'name'     => __( 'Gift wrap prompt location', 'woocommerce-gift-wrapper' ),
			'desc_tip' => __( 'Choose where to show gift wrap options to the customer on the cart page. You may choose more than one.', 'woocommerce-gift-wrapper' ),
			'type'     => 'multiselect',
			'default'  => 'none',
			'options'  => WC_Gift_Wrap()->settings->get_placements(),
			'css'      => 'min-height:110px',
			'autoload' => false
		];
		$settings[] = [
			'id'       => 'wcgwp_cart_display',
			'name'     => __( 'How should options be displayed?', 'woocommerce-gift-wrapper' ),
			'desc_tip' => __( 'If modal or slideToggle, there will be a prompt link ("header") in the cart, which when clicked will open a panel for customers to choose gift wrapping options. Checkbox and alternative modal display options available in the PLUS (paid) version.', 'woocommerce-gift-wrapper' ),
			'type'     => 'select',
			'default'  => 'modal',
			'options'  => [
				'modal'     => __( 'Modal/Popup', 'woocommerce-gift-wrapper' ),
				'slide'     => __( 'SlideToggle - uses jQuery', 'woocommerce-gift-wrapper' ),
				'checkbox'  => __( 'Checkbox', 'woocommerce-gift-wrapper' ),
			],
			'autoload' => false
		];
		$settings[] = [
			'id'        => 'wcgwp_checkbox_link',
			'name'      => __( 'Link checkbox label?', 'woocommerce-gift-wrapper-plus' ),
			'desc_tip'  => __( 'Should the checkbox label product title link to its WC product page?', 'woocommerce-gift-wrapper-plus' ),
			'type'      => 'select',
			'default'   => 'no',
			'options'   => [
				'yes'       => __( 'Yes', 'woocommerce-gift-wrapper-plus' ),
				'no'        => __( 'No', 'woocommerce-gift-wrapper-plus' ),
			],
			'autoload'  => false,
		];
		$settings[] = [
			'id'       => 'wcgwp_show_thumb',
			'name'     => __( 'Show thumbnails?', 'woocommerce-gift-wrapper' ),
			'desc_tip' => __( 'Should gift wrap product thumbnail images be visible in the cart?', 'woocommerce-gift-wrapper' ),
			'type'     => 'select',
			'default'  => 'yes',
			'options'  => [
				'yes' => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'  => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'autoload' => false,
		];
		$settings[] = [
			'id'       => 'wcgwp_link',
			'name'     => __( 'Link thumbnails?', 'woocommerce-gift-wrapper' ),
			'desc_tip' => __( 'Should thumbnail images link to gift wrap product details?', 'woocommerce-gift-wrapper' ),
			'type'     => 'select',
			'default'  => 'no',
			'options'  => [
				'yes' => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'  => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'autoload' => false
		];
		$settings[] = [
			'id'       => 'wcgwp_number',
			'name'     => __( 'Allow more than one gift wrap product in cart?', 'woocommerce-gift-wrapper' ),
			'desc_tip' => __( 'If yes, customers can buy more than one gift wrapping product in one order.', 'woocommerce-gift-wrapper' ),
			'type'     => 'select',
			'default'  => 'no',
			'options'  => [
				'yes'               => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'                => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'autoload' => false
		];
		$settings[] = [
			'id'       => 'wcgwp_number_max',
			'name'     => __( 'Max number of wrap products in cart', 'woocommerce-gift-wrapper' ),
			'desc_tip' => __( 'This setting only affects wrap added from peri-cart/checkout locations, not cart item or per-product wrapping.', 'woocommerce-gift-wrapper' ),
			'type'     => 'number',
			'default'  => 2,
			'min'      => 2,
			'max'      => 500,
			'class'    => 'wcgwp-number-max wcgwp-plus',
			'autoload' => false
		];
		$settings[] = [
			'id'       => 'wcgwp_hide_peri_wrap',
			'name'     => __( 'Hide prompts if wrap in cart?', 'woocommerce-gift-wrapper-plus' ),
			'desc_tip' => __( 'If there is any wrap in the cart (demonstrating that customer is aware wrapping is available) should prompts in cart/checkout area be hidden?', 'woocommerce-gift-wrapper-plus' ),
			'type'     => 'select',
			'default'  => 'no',
			'options'  => [
				'yes' => __( 'Yes', 'woocommerce-gift-wrapper-plus' ),
				'no'  => __( 'No', 'woocommerce-gift-wrapper-plus' ),
			],
			'class'    => 'wcgwp-plus',
			'autoload' => false
		];
		$settings[] = [
			'type' => 'sectionend'
		];

		return $settings;

	}

	/**
	 * Get product wrapping settings array
	 *
	 * @return array
	 */
	public function get_settings_for_product_wrapping_section() {

		$settings[] = [
			'name'              => '',
			'type'              => 'title',
			'id'                => 'wcgwp-plus-only-product',
			'desc'              => '<p><strong>' . sprintf( wp_kses( __( 'Per-product and line item gift wrapping options are available in the PLUS version of this plugin. <a href="%s" rel="noopener" target="_blank" class="button btn">Upgrade for better control</a>', 'woocommerce-gift-wrapper' ), [ 'a' => [ 'href' => [], 'target' => [], 'rel' => [], 'class' => [ 'button', 'btn' ] ] ] ), 'https://www.giftwrapper.app' ) . '</strong></p>',
		];
		$settings[] = [
			'type' => 'sectionend'
		];

		$settings[] = [
			'name'              => __( 'Product Gift Wrapping Settings', 'woocommerce-gift-wrapper' ),
			'type'              => 'title',
			'id'                => 'product-wrapping-title',
			'desc'              => __( 'Whereas order gift wrapping is non-specific and generally applies to an entire WooCommerce order,', 'woocommerce-gift-wrapper' )
								   . '<br />' . __( 'these Product Gift Wrapping settings allow more granular control over what products can be wrapped.', 'woocommerce-gift-wrapper' ),
		];
		$settings[] = [
			'id'                => 'wcgwp_all_products',
			'name'              => __( 'Gift wrapping', 'woocommerce-gift-wrapper' ),
			'desc'              => __( 'Enable Gift Wrap for All Products', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'If you check this box, gift wrapping will be enabled for your entire catalog, except for any excluded product categories, or individually excluded products.', 'woocommerce-gift-wrapper' )
								   . '<br />' . __( 'If this is not checked and you wish for per-product wrap control, you will need to enable wrap in the product settings for products you wish wrapped.', 'woocommerce-gift-wrapper' )
								   . '<br />' . __( 'If this is not checked and wrapping is not turned on for any individual products, no per-product wrapping will be offered.', 'woocommerce-gift-wrapper' ),
			'type'              => 'checkbox',
			'default'           => 'no',
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[]	= [
			'id'                => 'wcgwp_product_category_id',
			'title'             => __( 'Product page wrap category', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( '(Optional) Set a wrapping category to apply to single products. Can be overwritten in Woo single product settings. If not set, the gift wrap category in General Options applies.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'none',
			'options'           => WC_Gift_Wrap()->settings->product_cats(),
			'custom_attributes' => [
				'data-placeholder' => __( 'Define a Category', 'woocommerce-gift-wrapper' )
			],
			'class'             => 'chosen_select wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_exclude_cats',
			'name'              => __( 'Exclude product categories', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'Choose product categories to exclude from gift wrapping. You may choose more than one. You can exclude products individually using their Woo product settings pages.', 'woocommerce-gift-wrapper' ),
			'type'              => 'multiselect',
			'default'           => 0,
			'options'           => [],
			'custom_attributes' => [
				'data-placeholder'  => __( 'Exclude these categories (optional)', 'woocommerce-gift-wrapper' )
			],
			'class'             => 'chosen_select wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_product_show_thumb',
			'name'              => __( 'Show thumbnails?', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'Should gift wrap product thumbnail images be visible on product pages?', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'yes',
			'options'           => [
				'yes'   => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'    => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-product-show-thumb wcgwp-plus',
			'autoload'          => false,
		];

		$settings[] = [
			'id'                => 'wcgwp_product_link',
			'name'              => __( 'Link thumbnails?', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'Should thumbnail images link to gift wrap product details on product pages?', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'no',
			'options'           => [
				'yes'   => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'    => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-product-link wcgwp-plus',
			'autoload'          => false,
		];

		$settings[] = [
			'id'                => 'wcgwp_product_ratio',
			'name'              => __( 'Wrap Quantities', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( '(Beta setting) Dictate how many giftwraps can be in cart for each line item product. Loose control, in development.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'ad-lib',
			'options'           => [
				'ad-lib'            => __( 'Any quantity of wrap', 'woocommerce-gift-wrapper' ),
				'one-to-one'        => __( 'One-to-one wrap per product', 'woocommerce-gift-wrapper' ),
				'only-one'          => __( 'One wrap per product', 'woocommerce-gift-wrapper' ),
				'up-to-item-qty'    => __( 'Up to parent item quantity', 'woocommerce-gift-wrapper-plus' ),
				'up-to-cart-qty'    => __( 'Up to total quantity of products in cart', 'woocommerce-gift-wrapper-plus' ),
			],
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];

		$settings[] = [
			'id'                => 'wcgwp_cant_wrap_cue',
			'name'              => __( 'Cue when unwrappable?', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'If an item cannot be wrapped, should text be shown to alert the customer? This text can be translated on the strings page (link above) or by using filters.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'no',
			'options'           => [
				'yes'       => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'        => __( 'No', 'woocommerce-gift-wrapper' ),
				'product'   => __( 'Product page only', 'woocommerce-gift-wrapper' ),
				'cartitem'  => __( 'Inside cart only', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_show_relationship',
			'name'              => __( 'Show relationship?', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'You have chosen gift wrapping as its own cart item. Should the cart item show a more obvious relationship to the product it wraps, in the cart?', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'no',
			'options'           => [
				'yes'       => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'        => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'type'  => 'sectionend'
		];

		$settings[] = [
			'name'              => __( 'Wrap on Product pages', 'woocommerce-gift-wrapper' ),
			'type'              => 'title',
		];
		$settings[] = [
			'id'                => 'wcgwp_per_product_type',
			'name'              => __( 'Gift wrap from product pages?', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'Should product gift wrap be offered from product pages, and if so, as an attribute of parent product or its own line item when added to cart? If an attribute, separate tax rates cannot be used and gift wrap will not be inventoried.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'none',
			'options'           => [
				'no'        => __( 'No', 'woocommerce-gift-wrapper' ),
				'cartitem'  => __( 'Yes - Cart Item', 'woocommerce-gift-wrapper' ),
				'attribute' => __( 'Yes - as a Product Attribute', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_product_hook',
			'name'              => __( 'Gift wrap prompt location', 'woocommerce-gift-wrapper-plus' ),
			'desc_tip'          => __( 'Choose where to show gift wrap options to the customer on the product page. We recommend "Before Add to Cart." You may choose more than one.', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'multiselect',
			'default'           => 'woocommerce_before_add_to_cart_button',
			'options'           => [
				'woocommerce_before_add_to_cart_button' => __( 'Before Add to Cart Button', 'woocommerce-gift-wrapper-plus' ),
				'woocommerce_after_add_to_cart_button'  => __( 'After Add to Cart Button', 'woocommerce-gift-wrapper-plus' ),
				'other'                                 => __( 'Other, specify below:', 'woocommerce-gift-wrapper-plus' ),
			],
			'css'               => 'min-width:300px;',
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_other_product_hook',
			'name'              => __( 'Other location', 'woocommerce-gift-wrapper-plus' ),
			'desc_tip'          => __( 'Name a valid WP hook inside your product pages where a gift wrap prompt should attach. More than one? Separate with commas.', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'text',
			'default'           => '',
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_product_display',
			'name'              => __( 'Choose opt-in display type', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'A slide-down menu of options appears on the page (almost from out of nowhere) when a user asks to wrap. If modal, when gift wrap links are clicked, they will open a window for customers to choose gift wrapping options. It can be styled and might be a nicer option for your site; however a simple checkbox can be just as effective.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'modal',
			'options'           => [
				'modal'     => __( 'Modal/Popup', 'woocommerce-gift-wrapper' ),
				'alt'       => __( 'Modal/Popup - alternate style', 'woocommerce-gift-wrapper' ),
				'slide'     => __( 'SlideToggle - uses jQuery', 'woocommerce-gift-wrapper' ),
				'checkbox'  => __( 'Checkbox', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_checkbox_textarea',
			'name'              => __( 'Show textarea?', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'We noticed you chose to show a checkbox on product pages. Would you also like to include a note field?', 'woocommerce-gift-wrapper' )
							   . __( ' Note: if text limit is set to zero in General Options, this will not show.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'no',
			'options'           => [
				'yes'   => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'    => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'type'              => 'sectionend',
		];

		$settings[] = [
			'name'          => __( 'Per-product wrap inside Cart', 'woocommerce-gift-wrapper' ),
			'type'          => 'title'
		];
		$settings[] = [
			'id'            => 'wcgwp_cart_item_type',
			'name'          => __( 'Wrap products shown inside cart?', 'woocommerce-gift-wrapper' ),
			'desc_tip'      => __( 'Enables gift wrap inside the cart, per product. The customer will be able to add giftwrapping to products during checkout, except for any excluded product categories, or individually excluded products. Cart item wrap will sit on its own line. Attribute wrap becomes an Woo product attribute of the wrapped product.', 'woocommerce-gift-wrapper' ),
			'type'          => 'select',
			'default'       => 'no',
			'options'       => [
				'no'        => __( 'No', 'woocommerce-gift-wrapper' ),
				'cartitem'  => __( 'Yes - as a Cart Item', 'woocommerce-gift-wrapper' ),
				'attribute' => __( 'Yes - as a Product Attribute', 'woocommerce-gift-wrapper' ),
			],
			'class'         => 'wcgwp-plus',
			'autoload'      => false
		];
		$settings[] = [
			'id'                => 'wcgwp_cart_item_display',
			'name'              => __( 'Choose opt-in display type', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'If modal, when gift wrap links are clicked, they will open a separate, floating window for customers to choose gift wrapping options. It can be styled and might be a nicer option for your site.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'yes',
			'options'           => [
				'modal'             => __( 'Modal/Popup', 'woocommerce-gift-wrapper' ),
				'alt'               => __( 'Modal/Popup - alternate style', 'woocommerce-gift-wrapper' ),
				'slide'             => __( 'SlideToggle - uses jQuery', 'woocommerce-gift-wrapper' ),
			],
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_wrap_remove',
			'name'              => __( 'Allow customer to remove wrap from product in cart?', 'woocommerce-gift-wrapper' ),
			'desc_tip'          => __( 'Remove gift wrapping attribute without deleting the whole wrapped product from the cart.', 'woocommerce-gift-wrapper' ),
			'type'              => 'select',
			'default'           => 'yes',
			'options'           => [
				'yes'               => __( 'Yes', 'woocommerce-gift-wrapper' ),
				'no'                => __( 'No', 'woocommerce-gift-wrapper' ),
			],
			'autoload'          => false,
			'class'             => 'wcgwp-plus',
		];
		$settings[] = [
			'type' => 'sectionend',
		];

		return $settings;

	}

	/**
	 * Get language settings array
	 *
	 * @return array
	 */
	public function get_settings_for_language_section() {

		$settings[] = [
			'name'              => '',
			'type'              => 'title',
			'id'                => 'wcgwp-plus-only-lang',
			'desc'              => '<p><strong>' . sprintf( wp_kses( __( 'Easy string translations are available in the PLUS version of this plugin. <a href="%s" class="button btn" rel="noopener" target="_blank">Upgrade now</a>', 'woocommerce-gift-wrapper' ), [ 'a' => [ 'href' => [], 'target' => [], 'rel' => [], 'class' => [ 'btn','button' ] ] ] ), 'https://www.giftwrapper.app' ) . '</strong></p>',
		];
		$settings[] = [
			'type' => 'sectionend'
		];

		$settings[] = [
			'name'              => __( 'Language Matters', 'woocommerce-gift-wrapper' ),
			'type'              => 'title',
			'desc'              => __( 'Enter your adjustments or translations in the fields at right. Defaults are shown at left.' )
								. __( ' To make text disappear on the front end, you may need to use CSS (e.g. {style="display:none"} ), to hide enclosing elements. To use HTML, you will need to override included plugin template files.' ),
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[wrap]',
			'name'              => __( 'Gift wrap', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Gift wrap',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[add_wrap_prompt]',
			'name'              => __( 'Add gift wrap?', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Add gift wrap?',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[add_wrap_message]',
			'name'              => __( 'Add Gift Wrap Message:', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Add Gift Wrap Message:',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[add_wrap_to_order]',
			'name'              => __( 'Add Gift Wrap to Order:', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Add Gift Wrap to Order:',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[add_wrap_change]',
			'name'              => __( 'Gift wrap added. Change?', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Gift wrap added. Change?',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[cancel]',
			'name'              => __( 'Cancel', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Cancel',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[cancel_remove]',
			'name'              => __( 'Cancel/Remove', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Cancel/Remove',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[remove_wrap_prompt]',
			'name'              => __( 'Remove gift wrap?', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Remove gift wrap?',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[cancel_wrap]',
			'name'              => __( 'Cancel gift wrap', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Cancel gift wrap',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[add_wrap_for_x]',
			'name'              => __( 'Add gift wrapping for %s?', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Add gift wrapping for %s?',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[add_x_for_x]',
			'name'              => __( 'Add %s for %s?', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'text',
			'default'           => 'Add %s for %s?',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[wrap_details]',
			'name'              => __( 'We offer the following gift wrap options:', 'woocommerce-gift-wrapper' ),
			'type'              => 'textarea',
			'css'               => 'height: 75px;',
			'default'           => 'We offer the following gift wrap options:',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[replace]',
			'name'              => __( 'Are you sure you want to replace the gift wrap in your cart?', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Are you sure you want to replace the gift wrap in your cart?',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[cant_wrap]',
			'name'              => __( 'Sorry, this item cannot be gift wrapped.', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Sorry, this item cannot be gift wrapped.',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[for]',
			'name'              => __( 'For', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'For',
			'class'             => 'wcgwp-plus',
			'autoload'          => false,
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[note]',
			'name'              => __( 'Note', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Note',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[note_fee]',
			'name'              => __( 'Note fee', 'woocommerce-gift-wrapper' ),
			'type'              => 'text',
			'default'           => 'Note fee',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[no_product]',
			'name'              => __( 'Please choose a gift wrap product to continue.', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'text',
			'default'           => 'Please choose a gift wrap product to continue.',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[one_to_one]',
			'name'              => __( 'Only one gift wrap is allowed per item.', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'text',
			'default'           => 'Only one gift wrap is allowed per item.',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[only_one]',
			'name'              => __( 'Only one gift wrap is allowed per item purchase.', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'text',
			'default'           => 'Only one gift wrap is allowed per item purchase.',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] =[
			'id'                => 'wcgwp_strings[up_to_item_qty]',
			'name'              => __( 'Gift wrap quantity cannot exceed quantity of your item.', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'text',
			'default'           => 'You cannot have more gift wrap than items.',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'id'                => 'wcgwp_strings[up_to_cart_qty]',
			'name'              => __( 'You cannot have more gift wrap than items in cart.', 'woocommerce-gift-wrapper-plus' ),
			'type'              => 'text',
			'default'           => 'You cannot have more gift wrap than items in cart.',
			'class'             => 'wcgwp-plus',
			'autoload'          => false
		];
		$settings[] = [
			'type'  => 'sectionend'
		];

		return $settings;

	}

	/**
	 * Output the settings.
	 */
	public function output() {

		global $current_section, $hide_save_button;

		if ( 'product_wrapping' === $current_section ) {
			$hide_save_button = true;
		}
		$settings = $this->get_settings_for_section( $current_section );

		WC_Admin_Settings::output_fields( $settings );

	}

}